@@ -1,14 +1,14 @@
 /*
  *   Enums.h
  *
- *   Author: mat and jtr
+ *   Authors: mat and jtr
  */
 
 #ifndef FLEXBAR_ENUMS_H_
 #define FLEXBAR_ENUMS_H_
 
 
-/* These enums are used by almost every class. */
+// These enums are used by almost every class.
 
 namespace flexbar{
 	
@@ -21,6 +21,12 @@ namespace flexbar{
 		MOD
 	};
 	
+	enum CompressionType {
+		UNCOMPRESSED,
+		GZ,
+		BZ2
+	};
+	
 	enum TrimEnd {
 		ANY,
 		LEFT,
@@ -51,6 +57,8 @@ namespace flexbar{
 	
 	enum AdapterRemoval {
 		NORMAL,
+		AONE,
+		ATWO,
 		AOFF
 	};
 	
@@ -61,15 +69,6 @@ namespace flexbar{
 		PAIRED_BARCODED
 	};
 	
-	std::string toFormatString(FileFormat format){
-		switch(format){
-			case FASTA:   return ".fasta";
-			case FASTQ:   return ".fastq";
-			case CSFASTA: return ".csfasta";
-			case CSFASTQ: return ".csfastq";
-		}
-		return ".unknown";
-	}
 }
 
 #endif /* FLEXBAR_ENUMS_H_ */
