@@ -3,10 +3,10 @@
    Authors:      Matthias Dodt and Johannes Roehr
 
    Description:  Flexbar - flexible barcode and adapter removal
-   Version:      2.34
+   Version:      2.4
    Copyright:    GPL version 3
 
-   SeqAn lib:    post release 1.4, revision 14066 on May 23, 2013
+   SeqAn lib:    release 1.4.1, revision 14262 on July 11, 2013
    TBB   lib:    version 4.0 update 5, stable release June 13, 2012
 ========================================================================*/
 
@@ -22,10 +22,8 @@ int main(int argc, const char* argv[]){
 	
 	using seqan::ArgumentParser;
 	
-	// performTest();
-	
-	const string version = "2.34";
-	const string date    = "May 23, 2013";
+	const string version = "2.4";
+	const string date    = "July 29, 2013";
 	
 	ArgumentParser parser("flexbar");
 	
@@ -33,8 +31,9 @@ int main(int argc, const char* argv[]){
 	parseCommandLine(parser, version, argc, argv);
 	
 	Options o;
+	initOptions(o, parser);
 	
-	loadProgramOptions(o, parser);
+	loadProgramOptions(o, parser, version);
 	loadBarcodesAndAdapters(o);
 	
 	startComputation(o);
