@@ -13,12 +13,12 @@
 /* Structure to store statistics for each generated FASTQ file
 (how many reads were discarded due to being to short, etc.) */
 
-template <typename TString, typename TIDString>
+template <typename TString, typename TIDString, typename TStream>
 class OutputFileStruct {
 	
 public:
 	
-	typedef SequenceOutputFilter<TString, TIDString> TOutputFilter;
+	typedef SequenceOutputFilter<TString, TIDString, TStream> TOutputFilter;
 	
 	TOutputFilter *f1, *f2, *single1, *single2;
 	
